==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/sv/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '',
  '<strong>User</strong> administration' => '',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '',
  'Account' => 'Konto',
  'Account Request for \'{displayName}\' has been approved.' => '',
  'Account Request for \'{displayName}\' has been declined.' => '',
  'Actions' => 'Actions',
  'Active users' => '',
  'Add Groups...' => 'Lägg till grupper...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => 'Lägg till ny katebori',
  'Add new field' => 'Lägg till nytt fält',
  'Add new group' => '',
  'Add new members...' => '',
  'Add new user' => 'Lägg till ny användare',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => 'Tillåt',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => '',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'Avbryt',
  'Click here to review' => '',
  'Confirm user deletion' => 'Bekräfta radering',
  'Could not load category.' => 'Kunde inte ladda kategori.',
  'Create new group' => '',
  'Create new profile category' => 'Skapa ny profilkategori',
  'Create new profile field' => 'Skapa nytt profilfält',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => '',
  'Default' => 'Default',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => '',
  'Default user profile visibility' => '',
  'Delete' => 'Ta bort',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => 'Radera inbjudan',
  'Deleted users' => '',
  'Disable' => 'Inaktivera',
  'Disabled' => 'Avaktiverad',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => 'Ändra profilkategori',
  'Edit profile field' => 'Ändra profilfält',
  'Edit user: {name}' => 'Ändra användare: {name}',
  'Enable' => 'Aktivera',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Aktiverad',
  'Group Manager' => '',
  'Group not found!' => 'Gruppen hittades inte!',
  'Group user not found!' => '',
  'Groups' => 'Grupper',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => 'Här kan du lägga till eller ändra profilkategorier & fält',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => 'Inbjudan kunde inte hittas',
  'Last login' => '',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '',
  'Manage groups' => '',
  'Manage profile attributes' => 'Hantera profilattribut',
  'Member since' => '',
  'Members' => 'Medlemmar',
  'Members can invite external users by email' => 'Användare kan bjuda in externa personer via e-post',
  'Message' => 'Medelande',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '',
  'New approval requests' => '',
  'New users can register' => 'Anonyma användare kan registrera sig',
  'No' => '',
  'No value found!' => '',
  'One or more user needs your approval as group admin.' => '',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '',
  'Overview' => 'Översikt',
  'Password' => 'Lösenord',
  'Pending approvals' => '',
  'Pending user approvals' => '',
  'Permanently delete' => '',
  'Permissions' => '',
  'Profile Permissions' => '',
  'Profiles' => '',
  'Remove from group' => '',
  'Require group admin approval after registration' => 'Kräv grupp administrators godkännande efter registrering',
  'Resend invitation email' => '',
  'Save' => 'Spara',
  'Search by name, email or id.' => '',
  'Select Groups' => 'Valda grupper',
  'Send & save' => '',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => 'Skicka inbjudan',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Inställningar',
  'Show group selection at registration' => '',
  'Subject' => 'Ämne',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Icke godkänd',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'Användaren hittades inte!',
  'Users' => 'Användare',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Yes' => '',
  'You can only delete empty categories!' => 'Du kan endast ta bort tomma kategorier!',
  'You cannot delete yourself!' => 'Du kan inte ta bort dig själv!',
  'never' => '',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/sv/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '',
  '<strong>User</strong> administration' => '',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '',
  'Account' => 'Konto',
  'Account Request for \'{displayName}\' has been approved.' => '',
  'Account Request for \'{displayName}\' has been declined.' => '',
  'Actions' => 'Actions',
  'Active users' => '',
  'Add Groups...' => 'Lägg till grupper...',
  'Add new category' => 'Lägg till ny katebori',
  'Add new field' => 'Lägg till nytt fält',
  'Add new group' => '',
  'Add new members...' => '',
  'Add new user' => 'Lägg till ny användare',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => 'Tillåt',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => '',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'Avbryt',
  'Click here to review' => '',
  'Confirm user deletion' => 'Bekräfta radering',
  'Could not load category.' => 'Kunde inte ladda kategori.',
  'Create new group' => '',
  'Create new profile category' => 'Skapa ny profilkategori',
  'Create new profile field' => 'Skapa nytt profilfält',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => '',
  'Default' => 'Default',
  'Default Profile Permissions' => '',
  'Default Sorting' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => '',
  'Default user profile visibility' => '',
  'Delete' => 'Ta bort',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => 'Radera inbjudan',
  'Deleted users' => '',
  'Disable' => 'Inaktivera',
  'Disabled' => 'Avaktiverad',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => 'Ändra profilkategori',
  'Edit profile field' => 'Ändra profilfält',
  'Edit user: {name}' => 'Ändra användare: {name}',
  'Enable' => 'Aktivera',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Aktiverad',
  'First name' => 'Förnamn',
  'Group Manager' => '',
  'Group not found!' => 'Gruppen hittades inte!',
  'Group user not found!' => '',
  'Groups' => 'Grupper',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => 'Här kan du lägga till eller ändra profilkategorier & fält',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => 'Inbjudan kunde inte hittas',
  'Last login' => '',
  'Last name' => 'Efternamn',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '',
  'Manage groups' => '',
  'Manage profile attributes' => 'Hantera profilattribut',
  'Member since' => 'Medlem sedan',
  'Members' => 'Medlemmar',
  'Members can invite external users by email' => 'Användare kan bjuda in externa personer via e-post',
  'Message' => 'Medelande',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '',
  'New approval requests' => '',
  'New users can register' => 'Anonyma användare kan registrera sig',
  'No' => '',
  'No value found!' => '',
  'None' => 'Inga',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => '',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '',
  'Overview' => 'Översikt',
  'Password' => 'Lösenord',
  'Pending approvals' => '',
  'Pending user approvals' => '',
  'People' => 'Personer',
  'Permanently delete' => '',
  'Permissions' => 'Behörigheter',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => '',
  'Protected' => 'Skyddad',
  'Protected group can not be deleted!' => '',
  'Remove from group' => '',
  'Require group admin approval after registration' => 'Kräv grupp administrators godkännande efter registrering',
  'Resend invitation email' => '',
  'Save' => 'Spara',
  'Search by name, email or id.' => '',
  'Select Groups' => 'Valda grupper',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Sänd &amp; avböj',
  'Send & save' => '',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => 'Skicka inbjudan',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Inställningar',
  'Show group selection at registration' => '',
  'Subject' => 'Ämne',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Icke godkänd',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'Användaren hittades inte!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => '',
  'You can only delete empty categories!' => 'Du kan endast ta bort tomma kategorier!',
  'You cannot delete yourself!' => 'Du kan inte ta bort dig själv!',
  'never' => 'aldrig',
);
